#!/bin/sh

# This program tests for a bug involving COMPUTE and long variable names

TEMPDIR=/tmp/pspp-tst-$$
TESTFILE=$TEMPDIR/`basename $0`.sps

# ensure that top_builddir  are absolute
if [ -z "$top_builddir" ] ; then top_builddir=. ; fi
if [ -z "$top_srcdir" ] ; then top_srcdir=. ; fi
top_builddir=`cd $top_builddir; pwd`
PSPP=$top_builddir/src/ui/terminal/pspp

# ensure that top_srcdir is absolute
top_srcdir=`cd $top_srcdir; pwd`

STAT_CONFIG_PATH=$top_srcdir/config
export STAT_CONFIG_PATH


cleanup()
{
     if [ x"$PSPP_TEST_NO_CLEANUP" != x ] ; then 
	echo "NOT cleaning $TEMPDIR" 
	return ; 
     fi
     cd /
     rm -rf $TEMPDIR
}


fail()
{
    echo $activity
    echo FAILED
    cleanup;
    exit 1;
}


no_result()
{
    echo $activity
    echo NO RESULT;
    cleanup;
    exit 2;
}

pass()
{
    cleanup;
    exit 0;
}

mkdir -p $TEMPDIR

cd $TEMPDIR

activity="Create prog"
cat > $TESTFILE <<EOF
DATA LIST LIST /longVariablename * x *.
BEGIN DATA.
1 2
3 4
END DATA.


COMPUTE longvariableName=100-longvariablename.

LIST.

EOF
if [ $? -ne 0 ] ; then no_result ; fi


activity="run prog"
$SUPERVISOR $PSPP --testing-mode $TESTFILE
if [ $? -ne 0 ] ; then fail ; fi


activity="compare output"
perl -pi -e 's/^\s*$//g' pspp.list
diff -b pspp.list - << EOF
1.1 DATA LIST.  Reading free-form data from INLINE.
+----------------+------+
|    Variable    |Format|
#================#======#
|longVariablename|F8.0  |
|x               |F8.0  |
+----------------+------+
longVariablename        x
---------------- -------- 
           99.00     2.00
           97.00     4.00
EOF
if [ $? -ne 0 ] ; then fail ; fi


pass;
